@@ -9,7 +9,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(match_array_or_regex match_regex_or_array);
 
-our $VERSION = '0.40'; # VERSION
+our $VERSION = '0.41'; # VERSION
 
 our %SPEC;
 
@@ -76,13 +76,15 @@ $SPEC{match_regex_or_array}{summary} = 'Alias for match_array_or_regex';
 __END__
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 SHARYANTO::Array::Util - Array-related utilities
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -93,22 +95,46 @@ version 0.40
 None are exported by default, but they are exportable.
 
 
-=head2 match_array_or_regex() -> any
+None are exported by default, but they are exportable.
 
-No arguments.
+=head2 match_array_or_regex(@args) -> any
+
+Check whether an item matches (list of) values/regexes.
+
+This routine can be used to match an item against a regex or a list of
+strings/regexes, e.g. when matching against an ACL.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<haystack>* => I<any>
+
+=item * B<needle>* => I<str>
+
+=back
 
 Return value:
 
-Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+=head2 match_regex_or_array(@args) -> any
 
-=head2 match_regex_or_array() -> any
+Alias for match_array_or_regex.
 
-No arguments.
+This routine can be used to match an item against a regex or a list of
+strings/regexes, e.g. when matching against an ACL.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<haystack>* => I<any>
+
+=item * B<needle>* => I<str>
+
+=back
 
 Return value:
 
-Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
-
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
