@@ -6,9 +6,14 @@ use warnings;
 
 require Exporter;
 our @ISA = qw(Exporter);
-our @EXPORT_OK = qw(mix_2_rgb_colors rand_rgb_color);
+our @EXPORT_OK = qw(
+                       mix_2_rgb_colors
+                       rand_rgb_color
+                       rgb2grayscale
+                       rgb2sepia
+               );
 
-our $VERSION = '0.40'; # VERSION
+our $VERSION = '0.41'; # VERSION
 
 sub mix_2_rgb_colors {
     my ($rgb1, $rgb2, $pct) = @_;
@@ -56,6 +61,38 @@ sub rand_rgb_color {
                );
 }
 
+sub rgb2grayscale {
+    my ($rgb) = @_;
+
+    $rgb =~ /^#?([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})$/o
+        or die "Invalid rgb color, must be in 'ffffff' form";
+    my $r = hex($1);
+    my $g = hex($2);
+    my $b = hex($3);
+
+    # basically we just average the R, G, B
+    my $avg = int(($r + $g + $b)/3);
+    return sprintf("%02x%02x%02x", $avg, $avg, $avg);
+}
+
+sub rgb2sepia {
+
+    my ($rgb) = @_;
+
+    $rgb =~ /^#?([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})([0-9A-Fa-f]{2})$/o
+        or die "Invalid rgb color, must be in 'ffffff' form";
+    my $r = hex($1);
+    my $g = hex($2);
+    my $b = hex($3);
+
+    # reference: http://www.techrepublic.com/blog/howdoi/how-do-i-convert-images-to-grayscale-and-sepia-tone-using-c/120
+    my $or = ($r*0.393) + ($g*0.769) + ($b*0.189);
+    my $og = ($r*0.349) + ($g*0.686) + ($b*0.168);
+    my $ob = ($r*0.272) + ($g*0.534) + ($b*0.131);
+    for ($or, $og, $ob) { $_ = 255 if $_ > 255 }
+    return sprintf("%02x%02x%02x", $or, $og, $ob);
+}
+
 1;
 # ABSTRACT: Color-related utilities
 
@@ -63,17 +100,24 @@ sub rand_rgb_color {
 __END__
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 SHARYANTO::Color::Util - Color-related utilities
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
- use SHARYANTO::Color::Util qw(mix_2_rgb_colors rand_rgb_color);
+ use SHARYANTO::Color::Util qw(
+     mix_2_rgb_colors
+     rand_rgb_color
+     rgb2grayscale
+     rgb2sepia
+ );
 
  say mix_2_rgb_colors('#ff0000', '#ffffff');     # pink (red + white)
  say mix_2_rgb_colors('ff0000', 'ffffff', 0.75); # pink with a whiter shade
@@ -81,6 +125,8 @@ version 0.40
  say rand_rgb_color();
  say rand_rgb_color('000000', '333333');         # limit range
 
+ say rgb2grayscale('ff3322');                    # =>
+
 =head1 DESCRIPTION
 
 =head1 FUNCTIONS
@@ -97,9 +143,21 @@ the closer to 1 the closer the resulting color to C<$rgb2>.
 Generate a random RGB color. You can specify the limit. Otherwise, they default
 to the full range (000000 to ffffff).
 
+=head2 rgb2grayscale($rgb) => RGB
+
+Convert C<$rgb> to grayscale RGB value.
+
+=head2 rgb2sepia($rgb) => RGB
+
+Convert C<$rgb> to sepia tone RGB value.
+
+
+None are exported by default, but they are exportable.
+
 =head1 TODO
 
-mix_rgb_colors() to mix several RGB colors.
+mix_rgb_colors() to mix several RGB colors. Args might be $rgb1, $rgb2, ... or
+$rgb1, $part1, $rgb2, $part2, ... (e.g. 'ffffff', 1, 'ff0000', 1, '00ff00', 2).
 
 =head1 AUTHOR
 
