@@ -1,3 +1,4 @@
+package SHARYANTO::YAML::Any_SyckOnly;
 package SHARYANTO::YAML::Any;
 
 # NOTE: temporary namespace, will eventually be refactored, tidied up, and sent
@@ -22,13 +23,15 @@ $YAML::Syck::ImplicitTyping = 1;
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
-SHARYANTO::YAML::Any - Pick a YAML implementation and use it.
+SHARYANTO::YAML::Any_SyckOnly - Pick a YAML implementation and use it.
 
 =head1 VERSION
 
-version 0.35
+version 0.41
 
 =for Pod::Coverage .*
 
@@ -43,6 +46,13 @@ This software is copyright (c) 2013 by Steven Haryanto.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 DESCRIPTION
+
+=head1 FUNCTIONS
+
+
+None are exported by default, but they are exportable.
+
 =cut
 
 
